intelligence_feeds

package
v0.20.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 20, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client for intelligence feeds API

func (*Client) DownloadFeedArchive

func (a *Client) DownloadFeedArchive(params *DownloadFeedArchiveParams, opts ...ClientOption) error

DownloadFeedArchive downloads the content as a zip archive for a given feed item ID

func (*Client) ListFeedTypes

func (a *Client) ListFeedTypes(params *ListFeedTypesParams, opts ...ClientOption) (*ListFeedTypesOK, error)

ListFeedTypes lists the accessible feed types for a given customer

func (*Client) QueryFeedArchives

func (a *Client) QueryFeedArchives(params *QueryFeedArchivesParams, opts ...ClientOption) (*QueryFeedArchivesOK, error)

QueryFeedArchives queries the accessible feed types for a customer returns a list of feed item i ds which can be later downloaded

func (*Client) SetTransport

func (a *Client) SetTransport(transport runtime.ClientTransport)

SetTransport changes the transport on the client

type ClientOption

type ClientOption func(*runtime.ClientOperation)

ClientOption is the option for Client methods

type ClientService

type ClientService interface {
	DownloadFeedArchive(params *DownloadFeedArchiveParams, opts ...ClientOption) error

	ListFeedTypes(params *ListFeedTypesParams, opts ...ClientOption) (*ListFeedTypesOK, error)

	QueryFeedArchives(params *QueryFeedArchivesParams, opts ...ClientOption) (*QueryFeedArchivesOK, error)

	SetTransport(transport runtime.ClientTransport)
}

ClientService is the interface for Client methods

func New

func New(transport runtime.ClientTransport, formats strfmt.Registry) ClientService

New creates a new intelligence feeds API client.

type DownloadFeedArchiveBadRequest

type DownloadFeedArchiveBadRequest struct {

	/* Trace-ID: submit to support if resolving an issue
	 */
	XCSTRACEID string

	/* Request limit per minute.
	 */
	XRateLimitLimit int64

	/* The number of requests remaining for the sliding one minute window.
	 */
	XRateLimitRemaining int64

	Payload *models.MsaspecResponseFields
}

DownloadFeedArchiveBadRequest describes a response with status code 400, with default header values.

Bad Request

func NewDownloadFeedArchiveBadRequest

func NewDownloadFeedArchiveBadRequest() *DownloadFeedArchiveBadRequest

NewDownloadFeedArchiveBadRequest creates a DownloadFeedArchiveBadRequest with default headers values

func (*DownloadFeedArchiveBadRequest) Code

Code gets the status code for the download feed archive bad request response

func (*DownloadFeedArchiveBadRequest) Error

func (*DownloadFeedArchiveBadRequest) GetPayload

func (*DownloadFeedArchiveBadRequest) IsClientError

func (o *DownloadFeedArchiveBadRequest) IsClientError() bool

IsClientError returns true when this download feed archive bad request response has a 4xx status code

func (*DownloadFeedArchiveBadRequest) IsCode

func (o *DownloadFeedArchiveBadRequest) IsCode(code int) bool

IsCode returns true when this download feed archive bad request response a status code equal to that given

func (*DownloadFeedArchiveBadRequest) IsRedirect

func (o *DownloadFeedArchiveBadRequest) IsRedirect() bool

IsRedirect returns true when this download feed archive bad request response has a 3xx status code

func (*DownloadFeedArchiveBadRequest) IsServerError

func (o *DownloadFeedArchiveBadRequest) IsServerError() bool

IsServerError returns true when this download feed archive bad request response has a 5xx status code

func (*DownloadFeedArchiveBadRequest) IsSuccess

func (o *DownloadFeedArchiveBadRequest) IsSuccess() bool

IsSuccess returns true when this download feed archive bad request response has a 2xx status code

func (*DownloadFeedArchiveBadRequest) String

type DownloadFeedArchiveForbidden

type DownloadFeedArchiveForbidden struct {

	/* Trace-ID: submit to support if resolving an issue
	 */
	XCSTRACEID string

	/* Request limit per minute.
	 */
	XRateLimitLimit int64

	/* The number of requests remaining for the sliding one minute window.
	 */
	XRateLimitRemaining int64

	Payload *models.MsaReplyMetaOnly
}

DownloadFeedArchiveForbidden describes a response with status code 403, with default header values.

Forbidden

func NewDownloadFeedArchiveForbidden

func NewDownloadFeedArchiveForbidden() *DownloadFeedArchiveForbidden

NewDownloadFeedArchiveForbidden creates a DownloadFeedArchiveForbidden with default headers values

func (*DownloadFeedArchiveForbidden) Code

Code gets the status code for the download feed archive forbidden response

func (*DownloadFeedArchiveForbidden) Error

func (*DownloadFeedArchiveForbidden) GetPayload

func (*DownloadFeedArchiveForbidden) IsClientError

func (o *DownloadFeedArchiveForbidden) IsClientError() bool

IsClientError returns true when this download feed archive forbidden response has a 4xx status code

func (*DownloadFeedArchiveForbidden) IsCode

func (o *DownloadFeedArchiveForbidden) IsCode(code int) bool

IsCode returns true when this download feed archive forbidden response a status code equal to that given

func (*DownloadFeedArchiveForbidden) IsRedirect

func (o *DownloadFeedArchiveForbidden) IsRedirect() bool

IsRedirect returns true when this download feed archive forbidden response has a 3xx status code

func (*DownloadFeedArchiveForbidden) IsServerError

func (o *DownloadFeedArchiveForbidden) IsServerError() bool

IsServerError returns true when this download feed archive forbidden response has a 5xx status code

func (*DownloadFeedArchiveForbidden) IsSuccess

func (o *DownloadFeedArchiveForbidden) IsSuccess() bool

IsSuccess returns true when this download feed archive forbidden response has a 2xx status code

func (*DownloadFeedArchiveForbidden) String

type DownloadFeedArchiveInternalServerError

type DownloadFeedArchiveInternalServerError struct {

	/* Trace-ID: submit to support if resolving an issue
	 */
	XCSTRACEID string

	/* Request limit per minute.
	 */
	XRateLimitLimit int64

	/* The number of requests remaining for the sliding one minute window.
	 */
	XRateLimitRemaining int64

	Payload *models.MsaspecResponseFields
}

DownloadFeedArchiveInternalServerError describes a response with status code 500, with default header values.

Internal Server Error

func NewDownloadFeedArchiveInternalServerError

func NewDownloadFeedArchiveInternalServerError() *DownloadFeedArchiveInternalServerError

NewDownloadFeedArchiveInternalServerError creates a DownloadFeedArchiveInternalServerError with default headers values

func (*DownloadFeedArchiveInternalServerError) Code

Code gets the status code for the download feed archive internal server error response

func (*DownloadFeedArchiveInternalServerError) Error

func (*DownloadFeedArchiveInternalServerError) GetPayload

func (*DownloadFeedArchiveInternalServerError) IsClientError

func (o *DownloadFeedArchiveInternalServerError) IsClientError() bool

IsClientError returns true when this download feed archive internal server error response has a 4xx status code

func (*DownloadFeedArchiveInternalServerError) IsCode

IsCode returns true when this download feed archive internal server error response a status code equal to that given

func (*DownloadFeedArchiveInternalServerError) IsRedirect

IsRedirect returns true when this download feed archive internal server error response has a 3xx status code

func (*DownloadFeedArchiveInternalServerError) IsServerError

func (o *DownloadFeedArchiveInternalServerError) IsServerError() bool

IsServerError returns true when this download feed archive internal server error response has a 5xx status code

func (*DownloadFeedArchiveInternalServerError) IsSuccess

IsSuccess returns true when this download feed archive internal server error response has a 2xx status code

func (*DownloadFeedArchiveInternalServerError) String

type DownloadFeedArchiveParams

type DownloadFeedArchiveParams struct {

	/* FeedItemID.

	   Feed ID
	*/
	FeedItemID string

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

DownloadFeedArchiveParams contains all the parameters to send to the API endpoint

for the download feed archive operation.

Typically these are written to a http.Request.

func NewDownloadFeedArchiveParams

func NewDownloadFeedArchiveParams() *DownloadFeedArchiveParams

NewDownloadFeedArchiveParams creates a new DownloadFeedArchiveParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewDownloadFeedArchiveParamsWithContext

func NewDownloadFeedArchiveParamsWithContext(ctx context.Context) *DownloadFeedArchiveParams

NewDownloadFeedArchiveParamsWithContext creates a new DownloadFeedArchiveParams object with the ability to set a context for a request.

func NewDownloadFeedArchiveParamsWithHTTPClient

func NewDownloadFeedArchiveParamsWithHTTPClient(client *http.Client) *DownloadFeedArchiveParams

NewDownloadFeedArchiveParamsWithHTTPClient creates a new DownloadFeedArchiveParams object with the ability to set a custom HTTPClient for a request.

func NewDownloadFeedArchiveParamsWithTimeout

func NewDownloadFeedArchiveParamsWithTimeout(timeout time.Duration) *DownloadFeedArchiveParams

NewDownloadFeedArchiveParamsWithTimeout creates a new DownloadFeedArchiveParams object with the ability to set a timeout on a request.

func (*DownloadFeedArchiveParams) SetContext

func (o *DownloadFeedArchiveParams) SetContext(ctx context.Context)

SetContext adds the context to the download feed archive params

func (*DownloadFeedArchiveParams) SetDefaults

func (o *DownloadFeedArchiveParams) SetDefaults()

SetDefaults hydrates default values in the download feed archive params (not the query body).

All values with no default are reset to their zero value.

func (*DownloadFeedArchiveParams) SetFeedItemID

func (o *DownloadFeedArchiveParams) SetFeedItemID(feedItemID string)

SetFeedItemID adds the feedItemId to the download feed archive params

func (*DownloadFeedArchiveParams) SetHTTPClient

func (o *DownloadFeedArchiveParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the download feed archive params

func (*DownloadFeedArchiveParams) SetTimeout

func (o *DownloadFeedArchiveParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the download feed archive params

func (*DownloadFeedArchiveParams) WithContext

WithContext adds the context to the download feed archive params

func (*DownloadFeedArchiveParams) WithDefaults

WithDefaults hydrates default values in the download feed archive params (not the query body).

All values with no default are reset to their zero value.

func (*DownloadFeedArchiveParams) WithFeedItemID

func (o *DownloadFeedArchiveParams) WithFeedItemID(feedItemID string) *DownloadFeedArchiveParams

WithFeedItemID adds the feedItemID to the download feed archive params

func (*DownloadFeedArchiveParams) WithHTTPClient

func (o *DownloadFeedArchiveParams) WithHTTPClient(client *http.Client) *DownloadFeedArchiveParams

WithHTTPClient adds the HTTPClient to the download feed archive params

func (*DownloadFeedArchiveParams) WithTimeout

WithTimeout adds the timeout to the download feed archive params

func (*DownloadFeedArchiveParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type DownloadFeedArchivePermanentRedirect

type DownloadFeedArchivePermanentRedirect struct {

	/* Trace-ID: submit to support if resolving an issue
	 */
	XCSTRACEID string

	/* Request limit per minute.
	 */
	XRateLimitLimit int64

	/* The number of requests remaining for the sliding one minute window.
	 */
	XRateLimitRemaining int64

	/* Provides the download URL of a feed item. Available only if the provided feed ID is present and you have access to it.
	 */
	Location string

	Payload *models.MsaspecResponseFields
}

DownloadFeedArchivePermanentRedirect describes a response with status code 308, with default header values.

Permanent Redirect

func NewDownloadFeedArchivePermanentRedirect

func NewDownloadFeedArchivePermanentRedirect() *DownloadFeedArchivePermanentRedirect

NewDownloadFeedArchivePermanentRedirect creates a DownloadFeedArchivePermanentRedirect with default headers values

func (*DownloadFeedArchivePermanentRedirect) Code

Code gets the status code for the download feed archive permanent redirect response

func (*DownloadFeedArchivePermanentRedirect) Error

func (*DownloadFeedArchivePermanentRedirect) GetPayload

func (*DownloadFeedArchivePermanentRedirect) IsClientError

func (o *DownloadFeedArchivePermanentRedirect) IsClientError() bool

IsClientError returns true when this download feed archive permanent redirect response has a 4xx status code

func (*DownloadFeedArchivePermanentRedirect) IsCode

IsCode returns true when this download feed archive permanent redirect response a status code equal to that given

func (*DownloadFeedArchivePermanentRedirect) IsRedirect

IsRedirect returns true when this download feed archive permanent redirect response has a 3xx status code

func (*DownloadFeedArchivePermanentRedirect) IsServerError

func (o *DownloadFeedArchivePermanentRedirect) IsServerError() bool

IsServerError returns true when this download feed archive permanent redirect response has a 5xx status code

func (*DownloadFeedArchivePermanentRedirect) IsSuccess

IsSuccess returns true when this download feed archive permanent redirect response has a 2xx status code

func (*DownloadFeedArchivePermanentRedirect) String

type DownloadFeedArchiveReader

type DownloadFeedArchiveReader struct {
	// contains filtered or unexported fields
}

DownloadFeedArchiveReader is a Reader for the DownloadFeedArchive structure.

func (*DownloadFeedArchiveReader) ReadResponse

func (o *DownloadFeedArchiveReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type DownloadFeedArchiveTooManyRequests

type DownloadFeedArchiveTooManyRequests struct {

	/* Trace-ID: submit to support if resolving an issue
	 */
	XCSTRACEID string

	/* Request limit per minute.
	 */
	XRateLimitLimit int64

	/* The number of requests remaining for the sliding one minute window.
	 */
	XRateLimitRemaining int64

	/* Too many requests, retry after this time (as milliseconds since epoch)
	 */
	XRateLimitRetryAfter int64

	Payload *models.MsaReplyMetaOnly
}

DownloadFeedArchiveTooManyRequests describes a response with status code 429, with default header values.

Too Many Requests

func NewDownloadFeedArchiveTooManyRequests

func NewDownloadFeedArchiveTooManyRequests() *DownloadFeedArchiveTooManyRequests

NewDownloadFeedArchiveTooManyRequests creates a DownloadFeedArchiveTooManyRequests with default headers values

func (*DownloadFeedArchiveTooManyRequests) Code

Code gets the status code for the download feed archive too many requests response

func (*DownloadFeedArchiveTooManyRequests) Error

func (*DownloadFeedArchiveTooManyRequests) GetPayload

func (*DownloadFeedArchiveTooManyRequests) IsClientError

func (o *DownloadFeedArchiveTooManyRequests) IsClientError() bool

IsClientError returns true when this download feed archive too many requests response has a 4xx status code

func (*DownloadFeedArchiveTooManyRequests) IsCode

IsCode returns true when this download feed archive too many requests response a status code equal to that given

func (*DownloadFeedArchiveTooManyRequests) IsRedirect

func (o *DownloadFeedArchiveTooManyRequests) IsRedirect() bool

IsRedirect returns true when this download feed archive too many requests response has a 3xx status code

func (*DownloadFeedArchiveTooManyRequests) IsServerError

func (o *DownloadFeedArchiveTooManyRequests) IsServerError() bool

IsServerError returns true when this download feed archive too many requests response has a 5xx status code

func (*DownloadFeedArchiveTooManyRequests) IsSuccess

IsSuccess returns true when this download feed archive too many requests response has a 2xx status code

func (*DownloadFeedArchiveTooManyRequests) String

type ListFeedTypesBadRequest

type ListFeedTypesBadRequest struct {

	/* Trace-ID: submit to support if resolving an issue
	 */
	XCSTRACEID string

	/* Request limit per minute.
	 */
	XRateLimitLimit int64

	/* The number of requests remaining for the sliding one minute window.
	 */
	XRateLimitRemaining int64
}

ListFeedTypesBadRequest describes a response with status code 400, with default header values.

Bad Request

func NewListFeedTypesBadRequest

func NewListFeedTypesBadRequest() *ListFeedTypesBadRequest

NewListFeedTypesBadRequest creates a ListFeedTypesBadRequest with default headers values

func (*ListFeedTypesBadRequest) Code

func (o *ListFeedTypesBadRequest) Code() int

Code gets the status code for the list feed types bad request response

func (*ListFeedTypesBadRequest) Error

func (o *ListFeedTypesBadRequest) Error() string

func (*ListFeedTypesBadRequest) IsClientError

func (o *ListFeedTypesBadRequest) IsClientError() bool

IsClientError returns true when this list feed types bad request response has a 4xx status code

func (*ListFeedTypesBadRequest) IsCode

func (o *ListFeedTypesBadRequest) IsCode(code int) bool

IsCode returns true when this list feed types bad request response a status code equal to that given

func (*ListFeedTypesBadRequest) IsRedirect

func (o *ListFeedTypesBadRequest) IsRedirect() bool

IsRedirect returns true when this list feed types bad request response has a 3xx status code

func (*ListFeedTypesBadRequest) IsServerError

func (o *ListFeedTypesBadRequest) IsServerError() bool

IsServerError returns true when this list feed types bad request response has a 5xx status code

func (*ListFeedTypesBadRequest) IsSuccess

func (o *ListFeedTypesBadRequest) IsSuccess() bool

IsSuccess returns true when this list feed types bad request response has a 2xx status code

func (*ListFeedTypesBadRequest) String

func (o *ListFeedTypesBadRequest) String() string

type ListFeedTypesForbidden

type ListFeedTypesForbidden struct {

	/* Trace-ID: submit to support if resolving an issue
	 */
	XCSTRACEID string

	/* Request limit per minute.
	 */
	XRateLimitLimit int64

	/* The number of requests remaining for the sliding one minute window.
	 */
	XRateLimitRemaining int64

	Payload *models.MsaReplyMetaOnly
}

ListFeedTypesForbidden describes a response with status code 403, with default header values.

Forbidden

func NewListFeedTypesForbidden

func NewListFeedTypesForbidden() *ListFeedTypesForbidden

NewListFeedTypesForbidden creates a ListFeedTypesForbidden with default headers values

func (*ListFeedTypesForbidden) Code

func (o *ListFeedTypesForbidden) Code() int

Code gets the status code for the list feed types forbidden response

func (*ListFeedTypesForbidden) Error

func (o *ListFeedTypesForbidden) Error() string

func (*ListFeedTypesForbidden) GetPayload

func (*ListFeedTypesForbidden) IsClientError

func (o *ListFeedTypesForbidden) IsClientError() bool

IsClientError returns true when this list feed types forbidden response has a 4xx status code

func (*ListFeedTypesForbidden) IsCode

func (o *ListFeedTypesForbidden) IsCode(code int) bool

IsCode returns true when this list feed types forbidden response a status code equal to that given

func (*ListFeedTypesForbidden) IsRedirect

func (o *ListFeedTypesForbidden) IsRedirect() bool

IsRedirect returns true when this list feed types forbidden response has a 3xx status code

func (*ListFeedTypesForbidden) IsServerError

func (o *ListFeedTypesForbidden) IsServerError() bool

IsServerError returns true when this list feed types forbidden response has a 5xx status code

func (*ListFeedTypesForbidden) IsSuccess

func (o *ListFeedTypesForbidden) IsSuccess() bool

IsSuccess returns true when this list feed types forbidden response has a 2xx status code

func (*ListFeedTypesForbidden) String

func (o *ListFeedTypesForbidden) String() string

type ListFeedTypesInternalServerError

type ListFeedTypesInternalServerError struct {

	/* Trace-ID: submit to support if resolving an issue
	 */
	XCSTRACEID string

	/* Request limit per minute.
	 */
	XRateLimitLimit int64

	/* The number of requests remaining for the sliding one minute window.
	 */
	XRateLimitRemaining int64
}

ListFeedTypesInternalServerError describes a response with status code 500, with default header values.

Internal Server Error

func NewListFeedTypesInternalServerError

func NewListFeedTypesInternalServerError() *ListFeedTypesInternalServerError

NewListFeedTypesInternalServerError creates a ListFeedTypesInternalServerError with default headers values

func (*ListFeedTypesInternalServerError) Code

Code gets the status code for the list feed types internal server error response

func (*ListFeedTypesInternalServerError) Error

func (*ListFeedTypesInternalServerError) IsClientError

func (o *ListFeedTypesInternalServerError) IsClientError() bool

IsClientError returns true when this list feed types internal server error response has a 4xx status code

func (*ListFeedTypesInternalServerError) IsCode

func (o *ListFeedTypesInternalServerError) IsCode(code int) bool

IsCode returns true when this list feed types internal server error response a status code equal to that given

func (*ListFeedTypesInternalServerError) IsRedirect

func (o *ListFeedTypesInternalServerError) IsRedirect() bool

IsRedirect returns true when this list feed types internal server error response has a 3xx status code

func (*ListFeedTypesInternalServerError) IsServerError

func (o *ListFeedTypesInternalServerError) IsServerError() bool

IsServerError returns true when this list feed types internal server error response has a 5xx status code

func (*ListFeedTypesInternalServerError) IsSuccess

func (o *ListFeedTypesInternalServerError) IsSuccess() bool

IsSuccess returns true when this list feed types internal server error response has a 2xx status code

func (*ListFeedTypesInternalServerError) String

type ListFeedTypesOK

type ListFeedTypesOK struct {

	/* Trace-ID: submit to support if resolving an issue
	 */
	XCSTRACEID string

	/* Request limit per minute.
	 */
	XRateLimitLimit int64

	/* The number of requests remaining for the sliding one minute window.
	 */
	XRateLimitRemaining int64

	Payload *models.RestapiIndicatorGetFeedsResponse
}

ListFeedTypesOK describes a response with status code 200, with default header values.

OK

func NewListFeedTypesOK

func NewListFeedTypesOK() *ListFeedTypesOK

NewListFeedTypesOK creates a ListFeedTypesOK with default headers values

func (*ListFeedTypesOK) Code

func (o *ListFeedTypesOK) Code() int

Code gets the status code for the list feed types o k response

func (*ListFeedTypesOK) Error

func (o *ListFeedTypesOK) Error() string

func (*ListFeedTypesOK) GetPayload

func (*ListFeedTypesOK) IsClientError

func (o *ListFeedTypesOK) IsClientError() bool

IsClientError returns true when this list feed types o k response has a 4xx status code

func (*ListFeedTypesOK) IsCode

func (o *ListFeedTypesOK) IsCode(code int) bool

IsCode returns true when this list feed types o k response a status code equal to that given

func (*ListFeedTypesOK) IsRedirect

func (o *ListFeedTypesOK) IsRedirect() bool

IsRedirect returns true when this list feed types o k response has a 3xx status code

func (*ListFeedTypesOK) IsServerError

func (o *ListFeedTypesOK) IsServerError() bool

IsServerError returns true when this list feed types o k response has a 5xx status code

func (*ListFeedTypesOK) IsSuccess

func (o *ListFeedTypesOK) IsSuccess() bool

IsSuccess returns true when this list feed types o k response has a 2xx status code

func (*ListFeedTypesOK) String

func (o *ListFeedTypesOK) String() string

type ListFeedTypesParams

type ListFeedTypesParams struct {
	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

ListFeedTypesParams contains all the parameters to send to the API endpoint

for the list feed types operation.

Typically these are written to a http.Request.

func NewListFeedTypesParams

func NewListFeedTypesParams() *ListFeedTypesParams

NewListFeedTypesParams creates a new ListFeedTypesParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewListFeedTypesParamsWithContext

func NewListFeedTypesParamsWithContext(ctx context.Context) *ListFeedTypesParams

NewListFeedTypesParamsWithContext creates a new ListFeedTypesParams object with the ability to set a context for a request.

func NewListFeedTypesParamsWithHTTPClient

func NewListFeedTypesParamsWithHTTPClient(client *http.Client) *ListFeedTypesParams

NewListFeedTypesParamsWithHTTPClient creates a new ListFeedTypesParams object with the ability to set a custom HTTPClient for a request.

func NewListFeedTypesParamsWithTimeout

func NewListFeedTypesParamsWithTimeout(timeout time.Duration) *ListFeedTypesParams

NewListFeedTypesParamsWithTimeout creates a new ListFeedTypesParams object with the ability to set a timeout on a request.

func (*ListFeedTypesParams) SetContext

func (o *ListFeedTypesParams) SetContext(ctx context.Context)

SetContext adds the context to the list feed types params

func (*ListFeedTypesParams) SetDefaults

func (o *ListFeedTypesParams) SetDefaults()

SetDefaults hydrates default values in the list feed types params (not the query body).

All values with no default are reset to their zero value.

func (*ListFeedTypesParams) SetHTTPClient

func (o *ListFeedTypesParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the list feed types params

func (*ListFeedTypesParams) SetTimeout

func (o *ListFeedTypesParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the list feed types params

func (*ListFeedTypesParams) WithContext

WithContext adds the context to the list feed types params

func (*ListFeedTypesParams) WithDefaults

func (o *ListFeedTypesParams) WithDefaults() *ListFeedTypesParams

WithDefaults hydrates default values in the list feed types params (not the query body).

All values with no default are reset to their zero value.

func (*ListFeedTypesParams) WithHTTPClient

func (o *ListFeedTypesParams) WithHTTPClient(client *http.Client) *ListFeedTypesParams

WithHTTPClient adds the HTTPClient to the list feed types params

func (*ListFeedTypesParams) WithTimeout

func (o *ListFeedTypesParams) WithTimeout(timeout time.Duration) *ListFeedTypesParams

WithTimeout adds the timeout to the list feed types params

func (*ListFeedTypesParams) WriteToRequest

func (o *ListFeedTypesParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error

WriteToRequest writes these params to a swagger request

type ListFeedTypesReader

type ListFeedTypesReader struct {
	// contains filtered or unexported fields
}

ListFeedTypesReader is a Reader for the ListFeedTypes structure.

func (*ListFeedTypesReader) ReadResponse

func (o *ListFeedTypesReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type ListFeedTypesTooManyRequests

type ListFeedTypesTooManyRequests struct {

	/* Trace-ID: submit to support if resolving an issue
	 */
	XCSTRACEID string

	/* Request limit per minute.
	 */
	XRateLimitLimit int64

	/* The number of requests remaining for the sliding one minute window.
	 */
	XRateLimitRemaining int64

	/* Too many requests, retry after this time (as milliseconds since epoch)
	 */
	XRateLimitRetryAfter int64

	Payload *models.MsaReplyMetaOnly
}

ListFeedTypesTooManyRequests describes a response with status code 429, with default header values.

Too Many Requests

func NewListFeedTypesTooManyRequests

func NewListFeedTypesTooManyRequests() *ListFeedTypesTooManyRequests

NewListFeedTypesTooManyRequests creates a ListFeedTypesTooManyRequests with default headers values

func (*ListFeedTypesTooManyRequests) Code

Code gets the status code for the list feed types too many requests response

func (*ListFeedTypesTooManyRequests) Error

func (*ListFeedTypesTooManyRequests) GetPayload

func (*ListFeedTypesTooManyRequests) IsClientError

func (o *ListFeedTypesTooManyRequests) IsClientError() bool

IsClientError returns true when this list feed types too many requests response has a 4xx status code

func (*ListFeedTypesTooManyRequests) IsCode

func (o *ListFeedTypesTooManyRequests) IsCode(code int) bool

IsCode returns true when this list feed types too many requests response a status code equal to that given

func (*ListFeedTypesTooManyRequests) IsRedirect

func (o *ListFeedTypesTooManyRequests) IsRedirect() bool

IsRedirect returns true when this list feed types too many requests response has a 3xx status code

func (*ListFeedTypesTooManyRequests) IsServerError

func (o *ListFeedTypesTooManyRequests) IsServerError() bool

IsServerError returns true when this list feed types too many requests response has a 5xx status code

func (*ListFeedTypesTooManyRequests) IsSuccess

func (o *ListFeedTypesTooManyRequests) IsSuccess() bool

IsSuccess returns true when this list feed types too many requests response has a 2xx status code

func (*ListFeedTypesTooManyRequests) String

type QueryFeedArchivesBadRequest

type QueryFeedArchivesBadRequest struct {

	/* Trace-ID: submit to support if resolving an issue
	 */
	XCSTRACEID string

	/* Request limit per minute.
	 */
	XRateLimitLimit int64

	/* The number of requests remaining for the sliding one minute window.
	 */
	XRateLimitRemaining int64
}

QueryFeedArchivesBadRequest describes a response with status code 400, with default header values.

Bad Request

func NewQueryFeedArchivesBadRequest

func NewQueryFeedArchivesBadRequest() *QueryFeedArchivesBadRequest

NewQueryFeedArchivesBadRequest creates a QueryFeedArchivesBadRequest with default headers values

func (*QueryFeedArchivesBadRequest) Code

func (o *QueryFeedArchivesBadRequest) Code() int

Code gets the status code for the query feed archives bad request response

func (*QueryFeedArchivesBadRequest) Error

func (*QueryFeedArchivesBadRequest) IsClientError

func (o *QueryFeedArchivesBadRequest) IsClientError() bool

IsClientError returns true when this query feed archives bad request response has a 4xx status code

func (*QueryFeedArchivesBadRequest) IsCode

func (o *QueryFeedArchivesBadRequest) IsCode(code int) bool

IsCode returns true when this query feed archives bad request response a status code equal to that given

func (*QueryFeedArchivesBadRequest) IsRedirect

func (o *QueryFeedArchivesBadRequest) IsRedirect() bool

IsRedirect returns true when this query feed archives bad request response has a 3xx status code

func (*QueryFeedArchivesBadRequest) IsServerError

func (o *QueryFeedArchivesBadRequest) IsServerError() bool

IsServerError returns true when this query feed archives bad request response has a 5xx status code

func (*QueryFeedArchivesBadRequest) IsSuccess

func (o *QueryFeedArchivesBadRequest) IsSuccess() bool

IsSuccess returns true when this query feed archives bad request response has a 2xx status code

func (*QueryFeedArchivesBadRequest) String

func (o *QueryFeedArchivesBadRequest) String() string

type QueryFeedArchivesForbidden

type QueryFeedArchivesForbidden struct {

	/* Trace-ID: submit to support if resolving an issue
	 */
	XCSTRACEID string

	/* Request limit per minute.
	 */
	XRateLimitLimit int64

	/* The number of requests remaining for the sliding one minute window.
	 */
	XRateLimitRemaining int64

	Payload *models.MsaReplyMetaOnly
}

QueryFeedArchivesForbidden describes a response with status code 403, with default header values.

Forbidden

func NewQueryFeedArchivesForbidden

func NewQueryFeedArchivesForbidden() *QueryFeedArchivesForbidden

NewQueryFeedArchivesForbidden creates a QueryFeedArchivesForbidden with default headers values

func (*QueryFeedArchivesForbidden) Code

func (o *QueryFeedArchivesForbidden) Code() int

Code gets the status code for the query feed archives forbidden response

func (*QueryFeedArchivesForbidden) Error

func (*QueryFeedArchivesForbidden) GetPayload

func (*QueryFeedArchivesForbidden) IsClientError

func (o *QueryFeedArchivesForbidden) IsClientError() bool

IsClientError returns true when this query feed archives forbidden response has a 4xx status code

func (*QueryFeedArchivesForbidden) IsCode

func (o *QueryFeedArchivesForbidden) IsCode(code int) bool

IsCode returns true when this query feed archives forbidden response a status code equal to that given

func (*QueryFeedArchivesForbidden) IsRedirect

func (o *QueryFeedArchivesForbidden) IsRedirect() bool

IsRedirect returns true when this query feed archives forbidden response has a 3xx status code

func (*QueryFeedArchivesForbidden) IsServerError

func (o *QueryFeedArchivesForbidden) IsServerError() bool

IsServerError returns true when this query feed archives forbidden response has a 5xx status code

func (*QueryFeedArchivesForbidden) IsSuccess

func (o *QueryFeedArchivesForbidden) IsSuccess() bool

IsSuccess returns true when this query feed archives forbidden response has a 2xx status code

func (*QueryFeedArchivesForbidden) String

func (o *QueryFeedArchivesForbidden) String() string

type QueryFeedArchivesInternalServerError

type QueryFeedArchivesInternalServerError struct {

	/* Trace-ID: submit to support if resolving an issue
	 */
	XCSTRACEID string

	/* Request limit per minute.
	 */
	XRateLimitLimit int64

	/* The number of requests remaining for the sliding one minute window.
	 */
	XRateLimitRemaining int64
}

QueryFeedArchivesInternalServerError describes a response with status code 500, with default header values.

Internal Server Error

func NewQueryFeedArchivesInternalServerError

func NewQueryFeedArchivesInternalServerError() *QueryFeedArchivesInternalServerError

NewQueryFeedArchivesInternalServerError creates a QueryFeedArchivesInternalServerError with default headers values

func (*QueryFeedArchivesInternalServerError) Code

Code gets the status code for the query feed archives internal server error response

func (*QueryFeedArchivesInternalServerError) Error

func (*QueryFeedArchivesInternalServerError) IsClientError

func (o *QueryFeedArchivesInternalServerError) IsClientError() bool

IsClientError returns true when this query feed archives internal server error response has a 4xx status code

func (*QueryFeedArchivesInternalServerError) IsCode

IsCode returns true when this query feed archives internal server error response a status code equal to that given

func (*QueryFeedArchivesInternalServerError) IsRedirect

IsRedirect returns true when this query feed archives internal server error response has a 3xx status code

func (*QueryFeedArchivesInternalServerError) IsServerError

func (o *QueryFeedArchivesInternalServerError) IsServerError() bool

IsServerError returns true when this query feed archives internal server error response has a 5xx status code

func (*QueryFeedArchivesInternalServerError) IsSuccess

IsSuccess returns true when this query feed archives internal server error response has a 2xx status code

func (*QueryFeedArchivesInternalServerError) String

type QueryFeedArchivesOK

type QueryFeedArchivesOK struct {

	/* Trace-ID: submit to support if resolving an issue
	 */
	XCSTRACEID string

	/* Request limit per minute.
	 */
	XRateLimitLimit int64

	/* The number of requests remaining for the sliding one minute window.
	 */
	XRateLimitRemaining int64

	Payload *models.RestapiIndicatorFeedQueryResponse
}

QueryFeedArchivesOK describes a response with status code 200, with default header values.

OK

func NewQueryFeedArchivesOK

func NewQueryFeedArchivesOK() *QueryFeedArchivesOK

NewQueryFeedArchivesOK creates a QueryFeedArchivesOK with default headers values

func (*QueryFeedArchivesOK) Code

func (o *QueryFeedArchivesOK) Code() int

Code gets the status code for the query feed archives o k response

func (*QueryFeedArchivesOK) Error

func (o *QueryFeedArchivesOK) Error() string

func (*QueryFeedArchivesOK) GetPayload

func (*QueryFeedArchivesOK) IsClientError

func (o *QueryFeedArchivesOK) IsClientError() bool

IsClientError returns true when this query feed archives o k response has a 4xx status code

func (*QueryFeedArchivesOK) IsCode

func (o *QueryFeedArchivesOK) IsCode(code int) bool

IsCode returns true when this query feed archives o k response a status code equal to that given

func (*QueryFeedArchivesOK) IsRedirect

func (o *QueryFeedArchivesOK) IsRedirect() bool

IsRedirect returns true when this query feed archives o k response has a 3xx status code

func (*QueryFeedArchivesOK) IsServerError

func (o *QueryFeedArchivesOK) IsServerError() bool

IsServerError returns true when this query feed archives o k response has a 5xx status code

func (*QueryFeedArchivesOK) IsSuccess

func (o *QueryFeedArchivesOK) IsSuccess() bool

IsSuccess returns true when this query feed archives o k response has a 2xx status code

func (*QueryFeedArchivesOK) String

func (o *QueryFeedArchivesOK) String() string

type QueryFeedArchivesParams

type QueryFeedArchivesParams struct {

	/* FeedInterval.

	     Feed interval must be one of:
	- dump: Complete historical data snapshot
	- daily: Daily aggregated updates
	- hourly: Hourly incremental updates
	- minutely: Minute-by-minute updates
	- any: Automatically combines the appropriate intervals to provide complete, up-to-date data with minimal overlap

	Defaults to 'any' if not specified.
	*/
	FeedInterval *string

	/* FeedName.

	   Feed Name
	*/
	FeedName string

	/* Since.

	   Since is a valid timestamp in RFC3399 format. Restrictions: minutely: now()-2h, hourly: now()-2d, daily: now()-5d; dump: now()-7d
	*/
	Since *string

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

QueryFeedArchivesParams contains all the parameters to send to the API endpoint

for the query feed archives operation.

Typically these are written to a http.Request.

func NewQueryFeedArchivesParams

func NewQueryFeedArchivesParams() *QueryFeedArchivesParams

NewQueryFeedArchivesParams creates a new QueryFeedArchivesParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewQueryFeedArchivesParamsWithContext

func NewQueryFeedArchivesParamsWithContext(ctx context.Context) *QueryFeedArchivesParams

NewQueryFeedArchivesParamsWithContext creates a new QueryFeedArchivesParams object with the ability to set a context for a request.

func NewQueryFeedArchivesParamsWithHTTPClient

func NewQueryFeedArchivesParamsWithHTTPClient(client *http.Client) *QueryFeedArchivesParams

NewQueryFeedArchivesParamsWithHTTPClient creates a new QueryFeedArchivesParams object with the ability to set a custom HTTPClient for a request.

func NewQueryFeedArchivesParamsWithTimeout

func NewQueryFeedArchivesParamsWithTimeout(timeout time.Duration) *QueryFeedArchivesParams

NewQueryFeedArchivesParamsWithTimeout creates a new QueryFeedArchivesParams object with the ability to set a timeout on a request.

func (*QueryFeedArchivesParams) SetContext

func (o *QueryFeedArchivesParams) SetContext(ctx context.Context)

SetContext adds the context to the query feed archives params

func (*QueryFeedArchivesParams) SetDefaults

func (o *QueryFeedArchivesParams) SetDefaults()

SetDefaults hydrates default values in the query feed archives params (not the query body).

All values with no default are reset to their zero value.

func (*QueryFeedArchivesParams) SetFeedInterval

func (o *QueryFeedArchivesParams) SetFeedInterval(feedInterval *string)

SetFeedInterval adds the feedInterval to the query feed archives params

func (*QueryFeedArchivesParams) SetFeedName

func (o *QueryFeedArchivesParams) SetFeedName(feedName string)

SetFeedName adds the feedName to the query feed archives params

func (*QueryFeedArchivesParams) SetHTTPClient

func (o *QueryFeedArchivesParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the query feed archives params

func (*QueryFeedArchivesParams) SetSince

func (o *QueryFeedArchivesParams) SetSince(since *string)

SetSince adds the since to the query feed archives params

func (*QueryFeedArchivesParams) SetTimeout

func (o *QueryFeedArchivesParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the query feed archives params

func (*QueryFeedArchivesParams) WithContext

WithContext adds the context to the query feed archives params

func (*QueryFeedArchivesParams) WithDefaults

WithDefaults hydrates default values in the query feed archives params (not the query body).

All values with no default are reset to their zero value.

func (*QueryFeedArchivesParams) WithFeedInterval

func (o *QueryFeedArchivesParams) WithFeedInterval(feedInterval *string) *QueryFeedArchivesParams

WithFeedInterval adds the feedInterval to the query feed archives params

func (*QueryFeedArchivesParams) WithFeedName

func (o *QueryFeedArchivesParams) WithFeedName(feedName string) *QueryFeedArchivesParams

WithFeedName adds the feedName to the query feed archives params

func (*QueryFeedArchivesParams) WithHTTPClient

func (o *QueryFeedArchivesParams) WithHTTPClient(client *http.Client) *QueryFeedArchivesParams

WithHTTPClient adds the HTTPClient to the query feed archives params

func (*QueryFeedArchivesParams) WithSince

WithSince adds the since to the query feed archives params

func (*QueryFeedArchivesParams) WithTimeout

WithTimeout adds the timeout to the query feed archives params

func (*QueryFeedArchivesParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type QueryFeedArchivesReader

type QueryFeedArchivesReader struct {
	// contains filtered or unexported fields
}

QueryFeedArchivesReader is a Reader for the QueryFeedArchives structure.

func (*QueryFeedArchivesReader) ReadResponse

func (o *QueryFeedArchivesReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type QueryFeedArchivesTooManyRequests

type QueryFeedArchivesTooManyRequests struct {

	/* Trace-ID: submit to support if resolving an issue
	 */
	XCSTRACEID string

	/* Request limit per minute.
	 */
	XRateLimitLimit int64

	/* The number of requests remaining for the sliding one minute window.
	 */
	XRateLimitRemaining int64

	/* Too many requests, retry after this time (as milliseconds since epoch)
	 */
	XRateLimitRetryAfter int64

	Payload *models.MsaReplyMetaOnly
}

QueryFeedArchivesTooManyRequests describes a response with status code 429, with default header values.

Too Many Requests

func NewQueryFeedArchivesTooManyRequests

func NewQueryFeedArchivesTooManyRequests() *QueryFeedArchivesTooManyRequests

NewQueryFeedArchivesTooManyRequests creates a QueryFeedArchivesTooManyRequests with default headers values

func (*QueryFeedArchivesTooManyRequests) Code

Code gets the status code for the query feed archives too many requests response

func (*QueryFeedArchivesTooManyRequests) Error

func (*QueryFeedArchivesTooManyRequests) GetPayload

func (*QueryFeedArchivesTooManyRequests) IsClientError

func (o *QueryFeedArchivesTooManyRequests) IsClientError() bool

IsClientError returns true when this query feed archives too many requests response has a 4xx status code

func (*QueryFeedArchivesTooManyRequests) IsCode

func (o *QueryFeedArchivesTooManyRequests) IsCode(code int) bool

IsCode returns true when this query feed archives too many requests response a status code equal to that given

func (*QueryFeedArchivesTooManyRequests) IsRedirect

func (o *QueryFeedArchivesTooManyRequests) IsRedirect() bool

IsRedirect returns true when this query feed archives too many requests response has a 3xx status code

func (*QueryFeedArchivesTooManyRequests) IsServerError

func (o *QueryFeedArchivesTooManyRequests) IsServerError() bool

IsServerError returns true when this query feed archives too many requests response has a 5xx status code

func (*QueryFeedArchivesTooManyRequests) IsSuccess

func (o *QueryFeedArchivesTooManyRequests) IsSuccess() bool

IsSuccess returns true when this query feed archives too many requests response has a 2xx status code

func (*QueryFeedArchivesTooManyRequests) String

Jump to